------------------------------------------------------------
-- VHDL code for Top level wrapper 
-- Created on : 20th Aug, 2010
-- Author : Manish(mmk0002@auburn.edu)
------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

entity top_level is
port(
	clk: in std_logic;
	func:in std_logic_vector(1 downto 0);
	addr0: in std_logic_vector(4 downto 0);
	addr1: in std_logic_vector(4 downto 0);
	ovrfl: out std_logic;
	disp0: out std_logic_vector(6 downto 0);
	disp1: out std_logic_vector(6 downto 0);
	disp2: out std_logic_vector(6 downto 0);
	disp3: out std_logic_vector(6 downto 0)
);
end entity top_level;

architecture top_level_a of top_level is

-- Component Declarations
component mem0 is
PORT(
	address		: IN STD_LOGIC_VECTOR (7 DOWNTO 0);
	clock		: IN STD_LOGIC  := '0';
	data		: IN STD_LOGIC_VECTOR (15 DOWNTO 0);
	wren		: IN STD_LOGIC ;
	q		: OUT STD_LOGIC_VECTOR (15 DOWNTO 0)
);
end component;

component mem1 is
PORT(
	address		: IN STD_LOGIC_VECTOR (7 DOWNTO 0);
	clock		: IN STD_LOGIC  := '0';
	data		: IN STD_LOGIC_VECTOR (15 DOWNTO 0);
	wren		: IN STD_LOGIC ;
	q		: OUT STD_LOGIC_VECTOR (15 DOWNTO 0)
);
end component;

component alu is 
generic (n: integer := 16);
port(
	A : in std_logic_vector(n-1 downto 0);
	B : in std_logic_vector(n-1 downto 0);
	func : in std_logic_vector(1 downto 0);
	Z: out std_logic_vector(n-1 downto 0);
	ovrfl: out std_logic
);
end component alu;

component hexto7seg is 
port ( 
	hex_digit : in std_logic_vector(3 downto 0);
	segment :out std_logic_vector(6 downto 0)
);
end component hexto7seg;

--Signal Declaration
signal mem_to_alu_A, mem_to_alu_B, alu_out: std_logic_vector(15 downto 0);
 

begin
-- Port mapping to components
alu_inst: alu port map(mem_to_alu_A, mem_to_alu_B, func, alu_out, ovrfl);
memory0: mem0 port map("000"&addr0,clk,"0000000011111111",'0',mem_to_alu_A);
memory1: mem1 port map("000"&addr1,clk,"1111111100000000",'0',mem_to_alu_B);
hexto7seg0: hexto7seg port map(alu_out(3 downto 0), disp0);
hexto7seg1: hexto7seg port map(alu_out(7 downto 4), disp1);
hexto7seg2: hexto7seg port map(alu_out(11 downto 8), disp2);
hexto7seg3: hexto7seg port map(alu_out(15 downto 12), disp3);
end top_level_a;
